@@ -59,7 +59,7 @@ struct _GthOrganizeTaskPrivate
 };
 
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE (GthOrganizeTask, gth_organize_task, GTH_TYPE_TASK)
 
 
 static void
@@ -77,7 +77,7 @@ gth_organize_task_finalize (GObject *object)
 	g_object_unref (self->priv->icon_pixbuf);
 	g_object_unref (self->priv->filter);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_organize_task_parent_class)->finalize (object);
 }
 
 
@@ -541,7 +541,7 @@ static void
 gth_organize_task_exec (GthTask *base)
 {
 	GthOrganizeTask *self;
-	const char      *attributes = NULL;
+	const char      *attributes = "";
 
 	self = GTH_ORGANIZE_TASK (base);
 
@@ -628,7 +628,6 @@ gth_organize_task_class_init (GthOrganizeTaskClass *klass)
 	GObjectClass *object_class;
 	GthTaskClass *task_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthOrganizeTaskPrivate));
 
 	object_class = (GObjectClass*) klass;
@@ -801,7 +800,7 @@ gth_organize_task_init (GthOrganizeTask *self)
 						      gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GET_WIDGET ("organization_treeview"))));
 	g_object_unref (icon);
 
-	self->priv->file_list = gth_file_list_new (gth_icon_view_new (), GTH_FILE_LIST_TYPE_NORMAL, FALSE);
+	self->priv->file_list = gth_file_list_new (gth_grid_view_new (), GTH_FILE_LIST_TYPE_NORMAL, FALSE);
 	gth_file_list_set_caption (GTH_FILE_LIST (self->priv->file_list), "standard::display-name");
 	gtk_widget_show (self->priv->file_list);
 	gtk_box_pack_start (GTK_BOX (GET_WIDGET ("preview_box")), self->priv->file_list, TRUE, TRUE, 0);
@@ -837,34 +836,6 @@ gth_organize_task_init (GthOrganizeTask *self)
 }
 
 
-GType
-gth_organize_task_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthOrganizeTaskClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_organize_task_class_init,
-			NULL,
-			NULL,
-			sizeof (GthOrganizeTask),
-			0,
-			(GInstanceInitFunc) gth_organize_task_init
-		};
-
-		type = g_type_register_static (GTH_TYPE_TASK,
-					       "GthOrganizeTask",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthTask *
 gth_organize_task_new (GthBrowser     *browser,
 		       GFile          *folder,
