@@ -26,7 +26,7 @@
 #define GET_WIDGET(x) (_gtk_builder_get_widget (self->priv->builder, (x)))
 
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE (GthContactSheetThemeDialog, gth_contact_sheet_theme_dialog, GTK_TYPE_DIALOG)
 
 
 struct _GthContactSheetThemeDialogPrivate {
@@ -49,7 +49,7 @@ gth_contact_sheet_theme_dialog_finalize (GObject *object)
 	gth_contact_sheet_theme_unref (self->priv->theme);
 	gth_contact_sheet_theme_list_free (self->priv->all_themes);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_contact_sheet_theme_dialog_parent_class)->finalize (object);
 }
 
 
@@ -58,7 +58,6 @@ gth_contact_sheet_theme_dialog_class_init (GthContactSheetThemeDialogClass *klas
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthContactSheetThemeDialogPrivate));
 
 	object_class = (GObjectClass*) klass;
@@ -67,19 +66,16 @@ gth_contact_sheet_theme_dialog_class_init (GthContactSheetThemeDialogClass *klas
 
 
 static gboolean
-preview_area_expose_event_cb (GtkWidget      *widget,
-			      GdkEventExpose *event,
-			      gpointer        user_data)
+preview_area_draw_cb (GtkWidget *widget,
+		      cairo_t   *cr,
+		      gpointer   user_data)
 {
 	GthContactSheetThemeDialog *self = user_data;
-	cairo_t                    *cr;
 
-	cr = gdk_cairo_create (gtk_widget_get_window (widget));
 	gth_contact_sheet_theme_paint_preview (self->priv->theme,
 					       cr,
 					       gdk_window_get_width (gtk_widget_get_window (widget)),
 					       gdk_window_get_height (gtk_widget_get_window (widget)));
-	cairo_destroy (cr);
 
 	return TRUE;
 }
@@ -229,8 +225,8 @@ gth_contact_sheet_theme_dialog_init (GthContactSheetThemeDialog *self)
 	gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_OK);
 
 	g_signal_connect (GET_WIDGET ("preview_area"),
-			  "expose_event",
-			  G_CALLBACK (preview_area_expose_event_cb),
+			  "draw",
+			  G_CALLBACK (preview_area_draw_cb),
 			  self);
 	g_signal_connect_swapped (GET_WIDGET ("solid_color_radiobutton"),
 			  	  "toggled",
@@ -311,34 +307,6 @@ gth_contact_sheet_theme_dialog_init (GthContactSheetThemeDialog *self)
 }
 
 
-GType
-gth_contact_sheet_theme_dialog_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthContactSheetThemeDialogClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_contact_sheet_theme_dialog_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthContactSheetThemeDialog),
-			0,
-			(GInstanceInitFunc) gth_contact_sheet_theme_dialog_init,
-			NULL
-		};
-		type = g_type_register_static (GTK_TYPE_DIALOG,
-					       "GthContactSheetThemeDialog",
-					       &g_define_type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthContactSheetTheme *
 _gth_contact_sheet_theme_new_default (void)
 {
