@@ -28,7 +28,25 @@
 #include "gth-metadata-provider-exiv2.h"
 
 
-static GthMetadataProviderClass *parent_class = NULL;
+struct _GthMetadataProviderExiv2Private {
+	GSettings *general_settings;
+};
+
+
+G_DEFINE_TYPE (GthMetadataProviderExiv2, gth_metadata_provider_exiv2, GTH_TYPE_METADATA_PROVIDER)
+
+
+static void
+gth_metadata_provider_exiv2_finalize (GObject *object)
+{
+	GthMetadataProviderExiv2 *self;
+
+	self = GTH_METADATA_PROVIDER_EXIV2 (object);
+
+	_g_object_unref (self->priv->general_settings);
+
+	G_OBJECT_CLASS (gth_metadata_provider_exiv2_parent_class)->finalize (object);
+}
 
 
 static gboolean
@@ -108,19 +126,23 @@ gth_metadata_provider_exiv2_read (GthMetadataProvider *self,
 
 
 static void
-gth_metadata_provider_exiv2_write (GthMetadataProvider   *self,
+gth_metadata_provider_exiv2_write (GthMetadataProvider   *base,
 				   GthMetadataWriteFlags  flags,
 				   GthFileData           *file_data,
 				   const char            *attributes,
 				   GCancellable          *cancellable)
 {
-	void    *buffer = NULL;
-	gsize    size;
-	GError  *error = NULL;
-	GObject *metadata;
-	int      i;
+	GthMetadataProviderExiv2 *self = GTH_METADATA_PROVIDER_EXIV2 (base);
+	void                     *buffer = NULL;
+	gsize                     size;
+	GError                   *error = NULL;
+	GObject                  *metadata;
+	int                       i;
 
-	if (((flags & GTH_METADATA_WRITE_FORCE_EMBEDDED) != GTH_METADATA_WRITE_FORCE_EMBEDDED) && ! eel_gconf_get_boolean (PREF_STORE_METADATA_IN_FILES, TRUE))
+	if (self->priv->general_settings == NULL)
+		self->priv->general_settings = g_settings_new (GTHUMB_GENERAL_SCHEMA);
+
+	if (! (flags & GTH_METADATA_WRITE_FORCE_EMBEDDED) && ! g_settings_get_boolean (self->priv->general_settings, PREF_GENERAL_STORE_METADATA_IN_FILES))
 		return;
 
 	if (! exiv2_supports_writes (gth_file_data_get_mime_type (file_data)))
@@ -207,6 +229,18 @@ gth_metadata_provider_exiv2_write (GthMetadataProvider   *self,
 			g_file_info_remove_attribute (file_data->info, _KEYWORDS_TAG_NAMES[i]);
 	}
 
+	metadata = g_file_info_get_attribute_object (file_data->info, "general::rating");
+	if (metadata != NULL) {
+		if (GTH_IS_METADATA (metadata))
+			g_object_set (metadata, "value-type", NULL, NULL);
+		for (i = 0; _RATING_TAG_NAMES[i] != NULL; i++)
+			g_file_info_set_attribute_object (file_data->info, _RATING_TAG_NAMES[i], metadata);
+	}
+	else {
+		for (i = 0; _RATING_TAG_NAMES[i] != NULL; i++)
+			g_file_info_remove_attribute (file_data->info, _RATING_TAG_NAMES[i]);
+	}
+
 	metadata = g_file_info_get_attribute_object (file_data->info, "general::datetime");
 	if (metadata != NULL) {
 		GthMetadata *xmp_metadata = NULL;
@@ -283,38 +317,25 @@ gth_metadata_provider_exiv2_write (GthMetadataProvider   *self,
 static void
 gth_metadata_provider_exiv2_class_init (GthMetadataProviderExiv2Class *klass)
 {
-	parent_class = g_type_class_peek_parent (klass);
+	GObjectClass             *object_class;
+	GthMetadataProviderClass *mp_class;
 
-	GTH_METADATA_PROVIDER_CLASS (klass)->can_read = gth_metadata_provider_exiv2_can_read;
-	GTH_METADATA_PROVIDER_CLASS (klass)->can_write = gth_metadata_provider_exiv2_can_write;
-	GTH_METADATA_PROVIDER_CLASS (klass)->read = gth_metadata_provider_exiv2_read;
-	GTH_METADATA_PROVIDER_CLASS (klass)->write = gth_metadata_provider_exiv2_write;
+	g_type_class_add_private (klass, sizeof (GthMetadataProviderExiv2Private));
+
+	object_class = G_OBJECT_CLASS (klass);
+	object_class->finalize = gth_metadata_provider_exiv2_finalize;
+
+	mp_class = GTH_METADATA_PROVIDER_CLASS (klass);
+	mp_class->can_read = gth_metadata_provider_exiv2_can_read;
+	mp_class->can_write = gth_metadata_provider_exiv2_can_write;
+	mp_class->read = gth_metadata_provider_exiv2_read;
+	mp_class->write = gth_metadata_provider_exiv2_write;
 }
 
 
-GType
-gth_metadata_provider_exiv2_get_type (void)
+static void
+gth_metadata_provider_exiv2_init (GthMetadataProviderExiv2 *self)
 {
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthMetadataProviderExiv2Class),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_metadata_provider_exiv2_class_init,
-			NULL,
-			NULL,
-			sizeof (GthMetadataProviderExiv2),
-			0,
-			(GInstanceInitFunc) NULL
-		};
-
-		type = g_type_register_static (GTH_TYPE_METADATA_PROVIDER,
-					       "GthMetadataProviderExiv2",
-					       &type_info,
-					       0);
-	}
-
-	return type;
+	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_METADATA_PROVIDER_EXIV2, GthMetadataProviderExiv2Private);
+	self->priv->general_settings = NULL;
 }
