@@ -26,31 +26,37 @@
 #include "gth-image-viewer-page.h"
 #include "preferences.h"
 
-#define GTH_IMAGE_VIEWER_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTH_TYPE_IMAGE_VIEWER_PAGE, GthImageViewerPagePrivate))
-#define GCONF_NOTIFICATIONS 8
+
+static void gth_viewer_page_interface_init (GthViewerPageInterface *iface);
+
+
+G_DEFINE_TYPE_WITH_CODE (GthImageViewerPage,
+			 gth_image_viewer_page,
+			 G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (GTH_TYPE_VIEWER_PAGE,
+					        gth_viewer_page_interface_init))
 
 
 struct _GthImageViewerPagePrivate {
 	GthBrowser        *browser;
+	GSettings         *settings;
 	GtkWidget         *image_navigator;
 	GtkWidget         *viewer;
 	GthImagePreloader *preloader;
 	GtkActionGroup    *actions;
-	guint              merge_id;
+	guint              viewer_merge_id;
+	guint              browser_merge_id;
 	GthImageHistory   *history;
 	GthFileData       *file_data;
 	gulong             requested_ready_id;
 	gulong             original_size_ready_id;
-	guint              cnxn_id[GCONF_NOTIFICATIONS];
 	guint              hide_mouse_timeout;
 	guint              motion_signal;
 	gboolean           image_changed;
-	gboolean           shrink_wrap;
 	GFile             *last_loaded;
 	gboolean           can_paste;
 };
 
-static gpointer gth_image_viewer_page_parent_class = NULL;
 
 static const char *image_viewer_ui_info =
 "<ui>"
@@ -64,11 +70,6 @@ static const char *image_viewer_ui_info =
 "        <menuitem action='ImageViewer_Edit_Paste_Image'/>"
 "      </placeholder>"
 "    </menu>"
-"    <menu name='View' action='ViewMenu'>"
-"      <placeholder name='View_Actions'>"
-"        <menuitem action='ImageViewer_View_ShrinkWrap'/>"
-"      </placeholder>"
-"    </menu>"
 "  </menubar>"
 "  <toolbar name='ViewerToolBar'>"
 "    <placeholder name='ViewerCommands'>"
@@ -78,9 +79,6 @@ static const char *image_viewer_ui_info =
 "      <toolitem action='ImageViewer_View_ZoomFit'/>"
 "      <toolitem action='ImageViewer_View_ZoomFitWidth'/>"
 "    </placeholder>"
-"    <placeholder name='ViewerCommandsSecondary'>"
-"      <toolitem action='Viewer_Tools'/>"
-"    </placeholder>"
 "  </toolbar>"
 "  <toolbar name='Fullscreen_ToolBar'>"
 "    <placeholder name='ViewerCommands'>"
@@ -90,9 +88,6 @@ static const char *image_viewer_ui_info =
 "      <toolitem action='ImageViewer_View_ZoomFit'/>"
 "      <toolitem action='ImageViewer_View_ZoomFitWidth'/>"
 "    </placeholder>"
-"    <placeholder name='ViewerCommandsSecondary'>"
-"      <toolitem action='Viewer_Tools'/>"
-"    </placeholder>"
 "  </toolbar>"
 "</ui>";
 
@@ -169,14 +164,6 @@ image_viewer_activate_action_edit_paste_image (GtkAction          *action,
 }
 
 
-static void
-image_viewer_activate_action_view_shrink_wrap (GtkAction          *action,
-					       GthImageViewerPage *self)
-{
-	eel_gconf_set_boolean (PREF_VIEWER_SHRINK_WRAP, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
-}
-
-
 static GtkActionEntry image_viewer_action_entries[] = {
 	{ "ImageViewer_Edit_Undo", GTK_STOCK_UNDO,
 	  NULL, "<control>z",
@@ -225,15 +212,6 @@ static GtkActionEntry image_viewer_action_entries[] = {
 };
 
 
-static GtkToggleActionEntry image_viewer_toggle_action_entries[] = {
-	{ "ImageViewer_View_ShrinkWrap", NULL,
-	  N_("_Fit Window to Image"), "<control>e",
-	  N_("Resize the window to the size of the image"),
-	  G_CALLBACK (image_viewer_activate_action_view_shrink_wrap),
-	  FALSE }
-};
-
-
 static void
 gth_image_viewer_page_file_loaded (GthImageViewerPage *self,
 				   gboolean            success)
@@ -414,7 +392,7 @@ image_preloader_requested_ready_cb (GthImagePreloader  *preloader,
 	if (! _g_file_equal (requested->file, self->priv->file_data->file))
 		return;
 
-	if (error != NULL) {
+	if ((error != NULL) || (image == NULL)) {
 		gth_image_viewer_page_file_loaded (self, FALSE);
 		return;
 	}
@@ -426,12 +404,24 @@ image_preloader_requested_ready_cb (GthImagePreloader  *preloader,
 				    original_width,
 				    original_height);
 
-	if (self->priv->shrink_wrap)
-		gth_image_viewer_page_shrink_wrap (self, TRUE);
 	gth_image_history_clear (self->priv->history);
 	gth_image_history_add_image (self->priv->history,
 				     gth_image_viewer_get_current_image (GTH_IMAGE_VIEWER (self->priv->viewer)),
 				     FALSE);
+
+	if ((original_width == -1) || (original_height == -1))
+		/* In this case the image was loaded at its original size,
+		 * so we get the original size from the image surface size. */
+		gth_image_viewer_get_original_size (GTH_IMAGE_VIEWER (self->priv->viewer),
+						    &original_width,
+						    &original_height);
+	g_file_info_set_attribute_int32 (self->priv->file_data->info,
+					 "frame::width",
+					 original_width);
+	g_file_info_set_attribute_int32 (self->priv->file_data->info,
+					 "frame::height",
+					 original_height);
+
 	gth_image_viewer_page_file_loaded (self, TRUE);
 }
 
@@ -463,116 +453,97 @@ image_preloader_original_size_ready_cb (GthImagePreloader  *preloader,
 
 
 static void
-pref_zoom_quality_changed (GConfClient *client,
-			   guint        cnxn_id,
-			   GConfEntry  *entry,
-			   gpointer     user_data)
+pref_zoom_quality_changed (GSettings *settings,
+			   char      *key,
+			   gpointer   user_data)
 {
 	GthImageViewerPage *self = user_data;
-	GthImageViewer     *image_viewer = GTH_IMAGE_VIEWER (self->priv->viewer);
 
-	gth_image_viewer_set_zoom_quality (image_viewer, eel_gconf_get_enum (PREF_ZOOM_QUALITY, GTH_TYPE_ZOOM_QUALITY, GTH_ZOOM_QUALITY_HIGH));
-	gth_image_viewer_update_view (image_viewer);
+	gth_image_viewer_set_zoom_quality (GTH_IMAGE_VIEWER (self->priv->viewer),
+					   g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_ZOOM_QUALITY));
+	gtk_widget_queue_draw (self->priv->viewer);
 }
 
 
 static void
-pref_zoom_change_changed (GConfClient *client,
-			  guint        cnxn_id,
-			  GConfEntry  *entry,
-			  gpointer     user_data)
+pref_zoom_change_changed (GSettings *settings,
+		   	  char      *key,
+		   	  gpointer   user_data)
 {
 	GthImageViewerPage *self = user_data;
-	GthImageViewer     *image_viewer = GTH_IMAGE_VIEWER (self->priv->viewer);
 
-	gth_image_viewer_set_zoom_change (image_viewer, eel_gconf_get_enum (PREF_ZOOM_CHANGE, GTH_TYPE_ZOOM_CHANGE, GTH_ZOOM_CHANGE_FIT_SIZE_IF_LARGER));
-	gth_image_viewer_update_view (image_viewer);
+	gth_image_viewer_set_zoom_change (GTH_IMAGE_VIEWER (self->priv->viewer),
+					  g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_ZOOM_CHANGE));
+	gtk_widget_queue_draw (self->priv->viewer);
 }
 
 
 static void
-pref_transp_type_changed (GConfClient *client,
-			  guint        cnxn_id,
-			  GConfEntry  *entry,
-			  gpointer     user_data)
+pref_transp_type_changed (GSettings *settings,
+			  char      *key,
+			  gpointer   user_data)
 {
 	GthImageViewerPage *self = user_data;
-	GthImageViewer     *image_viewer = GTH_IMAGE_VIEWER (self->priv->viewer);
 
-	gth_image_viewer_set_transp_type (image_viewer, eel_gconf_get_enum (PREF_TRANSP_TYPE, GTH_TYPE_TRANSP_TYPE, GTH_TRANSP_TYPE_NONE));
-	gth_image_viewer_update_view (image_viewer);
+	gth_image_viewer_set_transp_type (GTH_IMAGE_VIEWER (self->priv->viewer),
+					  g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_TRANSP_TYPE));
+	gtk_widget_queue_draw (self->priv->viewer);
 }
 
 
 static void
-pref_check_type_changed (GConfClient *client,
-			 guint        cnxn_id,
-			 GConfEntry  *entry,
-			 gpointer     user_data)
+pref_check_type_changed (GSettings *settings,
+		   	 char      *key,
+		   	 gpointer   user_data)
 {
 	GthImageViewerPage *self = user_data;
-	GthImageViewer     *image_viewer = GTH_IMAGE_VIEWER (self->priv->viewer);
 
-	gth_image_viewer_set_check_type (image_viewer, eel_gconf_get_enum (PREF_CHECK_TYPE, GTH_TYPE_CHECK_TYPE, GTH_CHECK_TYPE_MIDTONE));
-	gth_image_viewer_update_view (image_viewer);
+	gth_image_viewer_set_check_type (GTH_IMAGE_VIEWER (self->priv->viewer),
+					 g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_CHECK_TYPE));
+	gtk_widget_queue_draw (self->priv->viewer);
 }
 
 
 static void
-pref_check_size_changed (GConfClient *client,
-			 guint        cnxn_id,
-			 GConfEntry  *entry,
-			 gpointer     user_data)
+pref_check_size_changed (GSettings *settings,
+		   	 char      *key,
+		   	 gpointer   user_data)
 {
 	GthImageViewerPage *self = user_data;
-	GthImageViewer     *image_viewer = GTH_IMAGE_VIEWER (self->priv->viewer);
 
-	gth_image_viewer_set_check_size (image_viewer, eel_gconf_get_enum (PREF_CHECK_SIZE, GTH_TYPE_CHECK_SIZE, GTH_CHECK_SIZE_MEDIUM));
-	gth_image_viewer_update_view (image_viewer);
+	gth_image_viewer_set_check_size (GTH_IMAGE_VIEWER (self->priv->viewer),
+					 g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_CHECK_SIZE));
+	gtk_widget_queue_draw (self->priv->viewer);
 }
 
 
 static void
-pref_black_background_changed (GConfClient *client,
-			       guint        cnxn_id,
-			       GConfEntry  *entry,
-			       gpointer     user_data)
+pref_black_background_changed (GSettings *settings,
+		   	       char      *key,
+		   	       gpointer   user_data)
 {
 	GthImageViewerPage *self = user_data;
-	GthImageViewer     *image_viewer = GTH_IMAGE_VIEWER (self->priv->viewer);
 
-	gth_image_viewer_set_black_background (image_viewer, eel_gconf_get_boolean (PREF_BLACK_BACKGROUND, FALSE));
+	gth_image_viewer_set_black_background (GTH_IMAGE_VIEWER (self->priv->viewer),
+					       g_settings_get_boolean (self->priv->settings, PREF_IMAGE_VIEWER_BLACK_BACKGROUND));
+	gtk_widget_queue_draw (self->priv->viewer);
 }
 
 
 static void
-pref_reset_scrollbars_changed (GConfClient *client,
-			       guint        cnxn_id,
-			       GConfEntry  *entry,
-			       gpointer     user_data)
-{
-	GthImageViewerPage *self = user_data;
-	GthImageViewer     *image_viewer = GTH_IMAGE_VIEWER (self->priv->viewer);
-
-	gth_image_viewer_set_reset_scrollbars (image_viewer, eel_gconf_get_boolean (PREF_RESET_SCROLLBARS, TRUE));
-}
-
-
-static void
-pref_viewer_shrink_wrap_changed (GConfClient *client,
-				 guint        cnxn_id,
-				 GConfEntry  *entry,
-				 gpointer     user_data)
+pref_reset_scrollbars_changed (GSettings *settings,
+		   	       char      *key,
+		   	       gpointer   user_data)
 {
 	GthImageViewerPage *self = user_data;
 
-	gth_image_viewer_page_shrink_wrap (self, eel_gconf_get_boolean (PREF_VIEWER_SHRINK_WRAP, FALSE));
+	gth_image_viewer_set_reset_scrollbars (GTH_IMAGE_VIEWER (self->priv->viewer),
+					       g_settings_get_boolean (self->priv->settings, PREF_IMAGE_VIEWER_RESET_SCROLLBARS));
 }
 
 
 static void
 paint_comment_over_image_func (GthImageViewer *image_viewer,
-			       GdkEventExpose *event,
 			       cairo_t        *cr,
 			       gpointer        user_data)
 {
@@ -723,7 +694,6 @@ gth_image_viewer_page_real_activate (GthViewerPage *base,
 {
 	GthImageViewerPage *self;
 	GtkAction          *action;
-	int                 i;
 
 	self = (GthImageViewerPage*) base;
 
@@ -735,12 +705,11 @@ gth_image_viewer_page_real_activate (GthViewerPage *base,
 				      image_viewer_action_entries,
 				      G_N_ELEMENTS (image_viewer_action_entries),
 				      self);
-	gtk_action_group_add_toggle_actions (self->priv->actions,
-					     image_viewer_toggle_action_entries,
-					     G_N_ELEMENTS (image_viewer_toggle_action_entries),
-					     self);
 	gtk_ui_manager_insert_action_group (gth_browser_get_ui_manager (browser), self->priv->actions, 0);
 
+	action = gtk_action_group_get_action (gth_browser_get_actions (browser), "Viewer_Tools");
+	g_object_set (action, "sensitive", TRUE, NULL);
+
 	self->priv->preloader = gth_browser_get_image_preloader (browser);
 	self->priv->requested_ready_id = g_signal_connect (G_OBJECT (self->priv->preloader),
 							   "requested_ready",
@@ -752,18 +721,20 @@ gth_image_viewer_page_real_activate (GthViewerPage *base,
 							       self);
 
 	self->priv->viewer = gth_image_viewer_new ();
-	gth_image_viewer_set_zoom_quality (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_enum (PREF_ZOOM_QUALITY, GTH_TYPE_ZOOM_QUALITY, GTH_ZOOM_QUALITY_HIGH));
-	gth_image_viewer_set_zoom_change (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_enum (PREF_ZOOM_CHANGE, GTH_TYPE_ZOOM_CHANGE, GTH_ZOOM_CHANGE_FIT_SIZE_IF_LARGER));
-	gth_image_viewer_set_transp_type (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_enum (PREF_TRANSP_TYPE, GTH_TYPE_TRANSP_TYPE, GTH_TRANSP_TYPE_NONE));
-	gth_image_viewer_set_check_type (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_enum (PREF_CHECK_TYPE, GTH_TYPE_CHECK_TYPE, GTH_CHECK_TYPE_MIDTONE));
-	gth_image_viewer_set_check_size (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_enum (PREF_CHECK_SIZE, GTH_TYPE_CHECK_SIZE, GTH_CHECK_SIZE_MEDIUM));
-	gth_image_viewer_set_black_background (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_boolean (PREF_BLACK_BACKGROUND, FALSE));
-	gth_image_viewer_set_reset_scrollbars (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_boolean (PREF_RESET_SCROLLBARS, TRUE));
-
-	self->priv->shrink_wrap = eel_gconf_get_boolean (PREF_VIEWER_SHRINK_WRAP, FALSE);
-	action = gtk_action_group_get_action (self->priv->actions, "ImageViewer_View_ShrinkWrap");
-	if (action != NULL)
-		g_object_set (action, "active", self->priv->shrink_wrap, NULL);
+	gth_image_viewer_set_zoom_quality (GTH_IMAGE_VIEWER (self->priv->viewer),
+					   g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_ZOOM_QUALITY));
+	gth_image_viewer_set_zoom_change (GTH_IMAGE_VIEWER (self->priv->viewer),
+					  g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_ZOOM_CHANGE));
+	gth_image_viewer_set_transp_type (GTH_IMAGE_VIEWER (self->priv->viewer),
+					  g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_TRANSP_TYPE));
+	gth_image_viewer_set_check_type (GTH_IMAGE_VIEWER (self->priv->viewer),
+					 g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_CHECK_TYPE));
+	gth_image_viewer_set_check_size (GTH_IMAGE_VIEWER (self->priv->viewer),
+					 g_settings_get_enum (self->priv->settings, PREF_IMAGE_VIEWER_CHECK_SIZE));
+	gth_image_viewer_set_black_background (GTH_IMAGE_VIEWER (self->priv->viewer),
+					       g_settings_get_boolean (self->priv->settings, PREF_IMAGE_VIEWER_BLACK_BACKGROUND));
+	gth_image_viewer_set_reset_scrollbars (GTH_IMAGE_VIEWER (self->priv->viewer),
+					       g_settings_get_boolean (self->priv->settings, PREF_IMAGE_VIEWER_RESET_SCROLLBARS));
 
 	gtk_widget_show (self->priv->viewer);
 
@@ -806,51 +777,36 @@ gth_image_viewer_page_real_activate (GthViewerPage *base,
 	gth_browser_set_viewer_widget (browser, self->priv->image_navigator);
 	gth_viewer_page_focus (GTH_VIEWER_PAGE (self));
 
-	/* gconf notifications */
+	/* settings notifications */
 
-	for (i = 0; i < GCONF_NOTIFICATIONS; i++)
-		self->priv->cnxn_id[i] = 0;
-
-	i = 0;
-	self->priv->cnxn_id[i++] = eel_gconf_notification_add (
-					   PREF_ZOOM_QUALITY,
-					   pref_zoom_quality_changed,
-					   self);
-
-	self->priv->cnxn_id[i++] = eel_gconf_notification_add (
-					   PREF_ZOOM_CHANGE,
-					   pref_zoom_change_changed,
-					   self);
-
-	self->priv->cnxn_id[i++] = eel_gconf_notification_add (
-					   PREF_TRANSP_TYPE,
-					   pref_transp_type_changed,
-					   self);
-
-	self->priv->cnxn_id[i++] = eel_gconf_notification_add (
-					   PREF_CHECK_TYPE,
-					   pref_check_type_changed,
-					   self);
-
-	self->priv->cnxn_id[i++] = eel_gconf_notification_add (
-					   PREF_CHECK_SIZE,
-					   pref_check_size_changed,
-					   self);
-
-	self->priv->cnxn_id[i++] = eel_gconf_notification_add (
-					   PREF_BLACK_BACKGROUND,
-					   pref_black_background_changed,
-					   self);
-
-	self->priv->cnxn_id[i++] = eel_gconf_notification_add (
-					   PREF_RESET_SCROLLBARS,
-					   pref_reset_scrollbars_changed,
-					   self);
-
-	self->priv->cnxn_id[i++] = eel_gconf_notification_add (
-					   PREF_VIEWER_SHRINK_WRAP,
-					   pref_viewer_shrink_wrap_changed,
-					   self);
+	g_signal_connect (self->priv->settings,
+			  "changed::" PREF_IMAGE_VIEWER_ZOOM_QUALITY,
+			  G_CALLBACK (pref_zoom_quality_changed),
+			  self);
+	g_signal_connect (self->priv->settings,
+			  "changed::" PREF_IMAGE_VIEWER_ZOOM_CHANGE,
+			  G_CALLBACK (pref_zoom_change_changed),
+			  self);
+	g_signal_connect (self->priv->settings,
+			  "changed::" PREF_IMAGE_VIEWER_TRANSP_TYPE,
+			  G_CALLBACK (pref_transp_type_changed),
+			  self);
+	g_signal_connect (self->priv->settings,
+			  "changed::" PREF_IMAGE_VIEWER_CHECK_TYPE,
+			  G_CALLBACK (pref_check_type_changed),
+			  self);
+	g_signal_connect (self->priv->settings,
+			  "changed::" PREF_IMAGE_VIEWER_CHECK_SIZE,
+			  G_CALLBACK (pref_check_size_changed),
+			  self);
+	g_signal_connect (self->priv->settings,
+			  "changed::" PREF_IMAGE_VIEWER_BLACK_BACKGROUND,
+			  G_CALLBACK (pref_black_background_changed),
+			  self);
+	g_signal_connect (self->priv->settings,
+			  "changed::" PREF_IMAGE_VIEWER_RESET_SCROLLBARS,
+			  G_CALLBACK (pref_reset_scrollbars_changed),
+			  self);
 }
 
 
@@ -858,17 +814,17 @@ static void
 gth_image_viewer_page_real_deactivate (GthViewerPage *base)
 {
 	GthImageViewerPage *self;
-	int                 i;
+	GtkAction          *action;
 
 	self = (GthImageViewerPage*) base;
 
-	/* remove gconf notifications */
+	action = gtk_action_group_get_action (gth_browser_get_actions (self->priv->browser), "Viewer_Tools");
+	g_object_set (action, "sensitive", FALSE, NULL);
 
-	for (i = 0; i < GCONF_NOTIFICATIONS; i++)
-		if (self->priv->cnxn_id[i] != 0)
-			eel_gconf_notification_remove (self->priv->cnxn_id[i]);
-
-	/**/
+	if (self->priv->browser_merge_id != 0) {
+		gtk_ui_manager_remove_ui (gth_browser_get_ui_manager (self->priv->browser), self->priv->browser_merge_id);
+		self->priv->browser_merge_id = 0;
+	}
 
 	gtk_ui_manager_remove_action_group (gth_browser_get_ui_manager (self->priv->browser), self->priv->actions);
 	g_object_unref (self->priv->actions);
@@ -894,11 +850,11 @@ gth_image_viewer_page_real_show (GthViewerPage *base)
 
 	self = (GthImageViewerPage*) base;
 
-	if (self->priv->merge_id != 0)
+	if (self->priv->viewer_merge_id != 0)
 		return;
 
-	self->priv->merge_id = gtk_ui_manager_add_ui_from_string (gth_browser_get_ui_manager (self->priv->browser), image_viewer_ui_info, -1, &error);
-	if (self->priv->merge_id == 0) {
+	self->priv->viewer_merge_id = gtk_ui_manager_add_ui_from_string (gth_browser_get_ui_manager (self->priv->browser), image_viewer_ui_info, -1, &error);
+	if (self->priv->viewer_merge_id == 0) {
 		g_warning ("ui building failed: %s", error->message);
 		g_error_free (error);
 	}
@@ -914,9 +870,9 @@ gth_image_viewer_page_real_hide (GthViewerPage *base)
 
 	self = (GthImageViewerPage*) base;
 
-	if (self->priv->merge_id != 0) {
-		gtk_ui_manager_remove_ui (gth_browser_get_ui_manager (self->priv->browser), self->priv->merge_id);
-		self->priv->merge_id = 0;
+	if (self->priv->viewer_merge_id != 0) {
+		gtk_ui_manager_remove_ui (gth_browser_get_ui_manager (self->priv->browser), self->priv->viewer_merge_id);
+		self->priv->viewer_merge_id = 0;
 	}
 }
 
@@ -1030,12 +986,13 @@ gth_image_viewer_page_real_fullscreen (GthViewerPage *base,
 	self = (GthImageViewerPage *) base;
 
 	if (active) {
-		gth_image_navigator_set_scrollbars_visible (GTH_IMAGE_NAVIGATOR (self->priv->image_navigator), FALSE);
+		gth_image_navigator_set_automatic_scrollbars (GTH_IMAGE_NAVIGATOR (self->priv->image_navigator), FALSE);
 		gth_image_viewer_set_black_background (GTH_IMAGE_VIEWER (self->priv->viewer), TRUE);
 	}
 	else {
-		gth_image_navigator_set_scrollbars_visible (GTH_IMAGE_NAVIGATOR (self->priv->image_navigator), TRUE);
-		gth_image_viewer_set_black_background (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_boolean (PREF_BLACK_BACKGROUND, FALSE));
+		gth_image_navigator_set_automatic_scrollbars (GTH_IMAGE_NAVIGATOR (self->priv->image_navigator), TRUE);
+		gth_image_viewer_set_black_background (GTH_IMAGE_VIEWER (self->priv->viewer),
+						       g_settings_get_boolean (self->priv->settings, PREF_IMAGE_VIEWER_BLACK_BACKGROUND));
 	}
 }
 
@@ -1085,12 +1042,22 @@ gth_image_viewer_page_real_update_sensitivity (GthViewerPage *base)
 
 typedef struct {
 	GthImageViewerPage *self;
+	GthFileData        *file_to_save;
 	GthFileData        *original_file;
 	FileSavedFunc       func;
 	gpointer            user_data;
 } SaveData;
 
 
+static void
+save_data_free (SaveData *data)
+{
+	g_object_unref (data->file_to_save);
+	g_object_unref (data->original_file);
+	g_free (data);
+}
+
+
 static void
 image_saved_cb (GthFileData *file_data,
 		GError      *error,
@@ -1103,17 +1070,12 @@ image_saved_cb (GthFileData *file_data,
 	error_occurred = error != NULL;
 
 	if (error_occurred) {
-		GthFileData *current_file;
-
-		current_file = gth_browser_get_current_file (self->priv->browser);
-		if (current_file != NULL) {
-			gth_file_data_set_file (current_file, data->original_file->file);
-			g_file_info_set_attribute_boolean (current_file->info, "gth::file::is-modified", FALSE);
-		}
+		gth_file_data_set_file (data->file_to_save, data->original_file->file);
+		g_file_info_set_attribute_boolean (data->file_to_save->info, "gth::file::is-modified", FALSE);
 	}
 
 	if (data->func != NULL)
-		(data->func) ((GthViewerPage *) self, self->priv->file_data, error, data->user_data);
+		(data->func) ((GthViewerPage *) self, data->file_to_save, error, data->user_data);
 	else if (error != NULL)
 		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (self->priv->browser), _("Could not save the file"), error);
 
@@ -1121,8 +1083,8 @@ image_saved_cb (GthFileData *file_data,
 		GFile *folder;
 		GList *file_list;
 
-		folder = g_file_get_parent (self->priv->file_data->file);
-		file_list = g_list_prepend (NULL, g_object_ref (self->priv->file_data->file));
+		folder = g_file_get_parent (data->file_to_save->file);
+		file_list = g_list_prepend (NULL, g_object_ref (data->file_to_save->file));
 		gth_monitor_folder_changed (gth_main_get_default_monitor (),
 					    folder,
 					    file_list,
@@ -1132,8 +1094,7 @@ image_saved_cb (GthFileData *file_data,
 		g_object_unref (folder);
 	}
 
-	g_object_unref (data->original_file);
-	g_free (data);
+	save_data_free (data);
 }
 
 
@@ -1160,14 +1121,35 @@ _gth_image_viewer_page_real_save (GthViewerPage *base,
 		mime_type = gth_file_data_get_mime_type (self->priv->file_data);
 
 	current_file = gth_browser_get_current_file (self->priv->browser);
+	if (current_file == NULL)
+		return;
+
+	data->file_to_save = g_object_ref (current_file);
 	data->original_file = gth_file_data_dup (current_file);
 	if (file != NULL)
-		gth_file_data_set_file (current_file, file);
-	g_file_info_set_attribute_boolean (current_file->info, "gth::file::is-modified", FALSE);
+		gth_file_data_set_file (data->file_to_save, file);
+
+	/* save the value of 'gth::file::is-modified' into 'gth::file::image-changed'
+	 * to allow the exiv2 metadata writer to not change some fields if the
+	 * content wasn't modified. */
+	g_file_info_set_attribute_boolean (data->file_to_save->info,
+					   "gth::file::image-changed",
+					   g_file_info_get_attribute_boolean (data->file_to_save->info, "gth::file::is-modified"));
+
+	/* the 'gth::file::is-modified' attribute must be set to false before
+	 * saving the file to avoid a scenario where the user is asked whether
+	 * he wants to save the file after saving it.
+	 * This is because when a file is modified in the current folder the
+	 * folder_changed_cb function in gth-browser.c is called automatically
+	 * and if the current file has been modified it is reloaded
+	 * (see file_attributes_ready_cb in gth-browser.c) and if it has been
+	 * modified ('gth::file::is-modified' is TRUE) the user is asked if he
+	 * wants to save (see load_file_delayed_cb in gth-browser.c). */
+	g_file_info_set_attribute_boolean (data->file_to_save->info, "gth::file::is-modified", FALSE);
 
 	pixbuf = gth_image_viewer_get_current_pixbuf (GTH_IMAGE_VIEWER (self->priv->viewer));
 	_gdk_pixbuf_save_async (pixbuf,
-			        current_file,
+				data->file_to_save,
 			        mime_type,
 			        TRUE,
 				image_saved_cb,
@@ -1287,7 +1269,7 @@ gth_image_viewer_page_real_save_as (GthViewerPage *base,
 			  data);
 
 	gtk_window_set_transient_for (GTK_WINDOW (file_sel), GTK_WINDOW (self->priv->browser));
-	gtk_window_set_modal (GTK_WINDOW (file_sel), FALSE);
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	gtk_widget_show (file_sel);
 
 	g_free (uri);
@@ -1355,7 +1337,7 @@ gth_image_viewer_page_real_update_info (GthViewerPage *base,
 	if (self->priv->viewer == NULL)
 		return;
 
-	gth_image_viewer_update_view (GTH_IMAGE_VIEWER (self->priv->viewer));
+	gtk_widget_queue_draw (self->priv->viewer);
 }
 
 
@@ -1371,7 +1353,18 @@ gth_image_viewer_page_real_show_properties (GthViewerPage *base,
 		gth_image_viewer_add_painter (GTH_IMAGE_VIEWER (self->priv->viewer), paint_comment_over_image_func, self);
 	else
 		gth_image_viewer_remove_painter (GTH_IMAGE_VIEWER (self->priv->viewer), paint_comment_over_image_func, self);
-	gth_image_viewer_update_view (GTH_IMAGE_VIEWER (self->priv->viewer));
+	gtk_widget_queue_draw (self->priv->viewer);
+}
+
+
+static void
+gth_image_viewer_page_real_shrink_wrap (GthViewerPage *base,
+					gboolean       activate,
+					int           *other_width,
+					int           *other_height)
+{
+	GthImageViewerPage *self = GTH_IMAGE_VIEWER_PAGE (base);
+	gth_image_viewer_set_fit_mode (GTH_IMAGE_VIEWER (self->priv->viewer), GTH_FIT_SIZE_IF_LARGER);
 }
 
 
@@ -1382,6 +1375,7 @@ gth_image_viewer_page_finalize (GObject *obj)
 
 	self = GTH_IMAGE_VIEWER_PAGE (obj);
 
+	g_object_unref (self->priv->settings);
 	g_object_unref (self->priv->history);
 	_g_object_unref (self->priv->file_data);
 	_g_object_unref (self->priv->last_loaded);
@@ -1393,7 +1387,6 @@ gth_image_viewer_page_finalize (GObject *obj)
 static void
 gth_image_viewer_page_class_init (GthImageViewerPageClass *klass)
 {
-	gth_image_viewer_page_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthImageViewerPagePrivate));
 
 	G_OBJECT_CLASS (klass)->finalize = gth_image_viewer_page_finalize;
@@ -1401,7 +1394,7 @@ gth_image_viewer_page_class_init (GthImageViewerPageClass *klass)
 
 
 static void
-gth_viewer_page_interface_init (GthViewerPageIface *iface)
+gth_viewer_page_interface_init (GthViewerPageInterface *iface)
 {
 	iface->activate = gth_image_viewer_page_real_activate;
 	iface->deactivate = gth_image_viewer_page_real_deactivate;
@@ -1419,46 +1412,21 @@ gth_viewer_page_interface_init (GthViewerPageIface *iface)
 	iface->revert = gth_image_viewer_page_real_revert;
 	iface->update_info = gth_image_viewer_page_real_update_info;
 	iface->show_properties = gth_image_viewer_page_real_show_properties;
+	iface->shrink_wrap = gth_image_viewer_page_real_shrink_wrap;
 }
 
 
 static void
-gth_image_viewer_page_instance_init (GthImageViewerPage *self)
+gth_image_viewer_page_init (GthImageViewerPage *self)
 {
-	self->priv = GTH_IMAGE_VIEWER_PAGE_GET_PRIVATE (self);
+	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_IMAGE_VIEWER_PAGE, GthImageViewerPagePrivate);
+	self->priv->settings = g_settings_new (GTHUMB_IMAGE_VIEWER_SCHEMA);
 	self->priv->history = gth_image_history_new ();
-	self->priv->shrink_wrap = FALSE;
 	self->priv->last_loaded = NULL;
 	self->priv->image_changed = FALSE;
 	self->priv->can_paste = FALSE;
-}
-
-
-GType
-gth_image_viewer_page_get_type (void) {
-	static GType gth_image_viewer_page_type_id = 0;
-	if (gth_image_viewer_page_type_id == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthImageViewerPageClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_image_viewer_page_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthImageViewerPage),
-			0,
-			(GInstanceInitFunc) gth_image_viewer_page_instance_init,
-			NULL
-		};
-		static const GInterfaceInfo gth_viewer_page_info = {
-			(GInterfaceInitFunc) gth_viewer_page_interface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL
-		};
-		gth_image_viewer_page_type_id = g_type_register_static (G_TYPE_OBJECT, "GthImageViewerPage", &g_define_type_info, 0);
-		g_type_add_interface_static (gth_image_viewer_page_type_id, GTH_TYPE_VIEWER_PAGE, &gth_viewer_page_info);
-	}
-	return gth_image_viewer_page_type_id;
+	self->priv->viewer_merge_id = 0;
+	self->priv->browser_merge_id = 0;
 }
 
 
@@ -1558,122 +1526,6 @@ gth_image_viewer_page_reset (GthImageViewerPage *self)
 }
 
 
-static int
-add_non_content_width (GthImageViewerPage *self,
-		       GtkWidget          *non_content)
-{
-	int width = 0;
-
-	if ((non_content != NULL) && gtk_widget_get_mapped (non_content)) {
-		GtkAllocation allocation;
-
-		gtk_widget_get_allocation (non_content, &allocation);
-		width = allocation.width;
-	}
-
-	return width;
-}
-
-
-static int
-add_non_content_height (GthImageViewerPage *self,
-			GtkWidget          *non_content)
-{
-	int height = 0;
-
-	if ((non_content != NULL) && gtk_widget_get_mapped (non_content)) {
-		GtkAllocation allocation;
-
-		gtk_widget_get_allocation (non_content, &allocation);
-		height = allocation.height;
-	}
-
-	return height;
-}
-
-
-void
-gth_image_viewer_page_shrink_wrap (GthImageViewerPage *self,
-				   gboolean            activate)
-{
-	GthFileData *file_data;
-	int          width;
-	int          height;
-	double       ratio;
-	int          other_width;
-	int          other_height;
-	GdkScreen   *screen;
-	int          max_width;
-	int          max_height;
-
-	self->priv->shrink_wrap = activate;
-	if (! self->priv->shrink_wrap) {
-		int width;
-		int height;
-
-		if (gth_window_get_page_size (GTH_WINDOW (self->priv->browser),
-					      GTH_BROWSER_PAGE_BROWSER,
-					      &width,
-					      &height))
-		{
-			gth_window_save_page_size (GTH_WINDOW (self->priv->browser), GTH_BROWSER_PAGE_VIEWER, width, height);
-			gth_window_apply_saved_size (GTH_WINDOW (self->priv->browser), GTH_BROWSER_PAGE_VIEWER);
-		}
-		else
-			gth_window_clear_saved_size (GTH_WINDOW (self->priv->browser), GTH_BROWSER_PAGE_VIEWER);
-		gth_image_viewer_set_fit_mode (GTH_IMAGE_VIEWER (self->priv->viewer), GTH_FIT_SIZE_IF_LARGER);
-
-		return;
-	}
-
-	file_data = gth_browser_get_current_file (self->priv->browser);
-	if (file_data == NULL)
-		return;
-
-	gth_image_viewer_get_original_size (GTH_IMAGE_VIEWER (self->priv->viewer), &width, &height);
-	if ((width <= 0) || (height <= 0))
-		return;
-
-	ratio = (double) width / height;
-
-	other_width = 0;
-	other_height = 0;
-	other_height += add_non_content_height (self, gth_window_get_area (GTH_WINDOW (self->priv->browser), GTH_WINDOW_MENUBAR));
-	other_height += add_non_content_height (self, gth_window_get_area (GTH_WINDOW (self->priv->browser), GTH_WINDOW_TOOLBAR));
-	other_height += add_non_content_height (self, gth_window_get_area (GTH_WINDOW (self->priv->browser), GTH_WINDOW_STATUSBAR));
-	other_height += add_non_content_height (self, gth_browser_get_viewer_toolbar (self->priv->browser));
-	if (eel_gconf_get_enum (PREF_UI_VIEWER_THUMBNAILS_ORIENT, GTK_TYPE_ORIENTATION, GTK_ORIENTATION_HORIZONTAL) == GTK_ORIENTATION_HORIZONTAL)
-		other_height += add_non_content_height (self, gth_browser_get_thumbnail_list (self->priv->browser));
-	else
-		other_width += add_non_content_width (self, gth_browser_get_thumbnail_list (self->priv->browser));
-	other_width += add_non_content_width (self, gth_browser_get_viewer_sidebar (self->priv->browser));
-	other_width += 2;
-	other_height += 2;
-
-	screen = gtk_widget_get_screen (GTK_WIDGET (self->priv->browser));
-	max_width = round ((double) gdk_screen_get_width (screen) * 8.5 / 10.0);
-	max_height = round ((double) gdk_screen_get_height (screen) * 8.5 / 10.0);
-
-	if (width + other_width > max_width) {
-		width = max_width - other_width;
-		height = width / ratio;
-	}
-
-	if (height + other_height > max_height) {
-		height = max_height - other_height;
-		width = height * ratio;
-	}
-
-	gth_window_save_page_size (GTH_WINDOW (self->priv->browser),
-				   GTH_BROWSER_PAGE_VIEWER,
-				   width + other_width,
-				   height + other_height);
-	if (gth_window_get_current_page (GTH_WINDOW (self->priv->browser)) == GTH_BROWSER_PAGE_VIEWER)
-		gth_window_apply_saved_size (GTH_WINDOW (self->priv->browser), GTH_BROWSER_PAGE_VIEWER);
-	gth_image_viewer_set_fit_mode (GTH_IMAGE_VIEWER (self->priv->viewer), GTH_FIT_SIZE_IF_LARGER);
-}
-
-
 void
 gth_image_viewer_page_copy_image (GthImageViewerPage *self)
 {
