@@ -31,6 +31,9 @@
 #define IMPORTED_KEY "imported"
 
 
+G_DEFINE_TYPE (GthImportTask, gth_import_task, GTH_TYPE_TASK)
+
+
 struct _GthImportTaskPrivate {
 	GthBrowser          *browser;
 	GList               *files;
@@ -62,9 +65,6 @@ struct _GthImportTaskPrivate {
 };
 
 
-static gpointer parent_class = NULL;
-
-
 static void
 gth_import_task_finalize (GObject *object)
 {
@@ -88,7 +88,7 @@ gth_import_task_finalize (GObject *object)
 	_g_object_unref (self->priv->imported_catalog);
 	g_object_unref (self->priv->browser);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_import_task_parent_class)->finalize (object);
 }
 
 
@@ -605,12 +605,15 @@ import_current_file (GthImportTask *self)
 			gtk_widget_show (d);
 		}
 		else {
+			GSettings *settings;
+
 			if ((self->priv->subfolder_type != GTH_SUBFOLDER_TYPE_NONE) && (self->priv->imported_catalog != NULL))
 				gth_browser_go_to (self->priv->browser, self->priv->imported_catalog, NULL);
 			else
 				gth_browser_go_to (self->priv->browser, self->priv->destination, NULL);
 
-			if (self->priv->delete_not_supported && eel_gconf_get_boolean (PREF_IMPORT_WARN_DELETE_UNSUPPORTED, TRUE)) {
+			settings = g_settings_new (GTHUMB_IMPORTER_SCHEMA);
+			if (self->priv->delete_not_supported && g_settings_get_boolean (settings, PREF_IMPORTER_WARN_DELETE_UNSUPPORTED)) {
 				GtkWidget *d;
 
 				d =  _gtk_message_dialog_new (GTK_WINDOW (self->priv->browser),
@@ -625,8 +628,10 @@ import_current_file (GthImportTask *self)
 						  NULL);
 				gtk_widget_show (d);
 
-				eel_gconf_set_boolean (PREF_IMPORT_WARN_DELETE_UNSUPPORTED, FALSE);
+				g_settings_set_boolean (settings, PREF_IMPORTER_WARN_DELETE_UNSUPPORTED, FALSE);
 			}
+
+			g_object_unref (settings);
 		}
 
 		gth_task_completed (GTH_TASK (self), NULL);
@@ -731,7 +736,6 @@ gth_import_task_class_init (GthImportTaskClass *klass)
 	GObjectClass *object_class;
 	GthTaskClass *task_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthImportTaskPrivate));
 
 	object_class = G_OBJECT_CLASS (klass);
@@ -756,34 +760,6 @@ gth_import_task_init (GthImportTask *self)
 }
 
 
-GType
-gth_import_task_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthImportTaskClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_import_task_class_init,
-			NULL,
-			NULL,
-			sizeof (GthImportTask),
-			0,
-			(GInstanceInitFunc) gth_import_task_init
-		};
-
-		type = g_type_register_static (GTH_TYPE_TASK,
-					       "GthImportTask",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthTask *
 gth_import_task_new (GthBrowser         *browser,
 		     GList              *files,
@@ -867,8 +843,8 @@ gth_import_task_check_free_space (GFile   *destination,
 		char *free_space_s;
 
 		destination_name = g_file_get_parse_name (destination);
-		min_free_space_s = g_format_size_for_display (min_free_space);
-		free_space_s = g_format_size_for_display (free_space);
+		min_free_space_s = g_format_size (min_free_space);
+		free_space_s = g_format_size (free_space);
 
 		*error = g_error_new (G_IO_ERROR,
 				      G_IO_ERROR_NO_SPACE,
